@@ -15,14 +15,8 @@ from pywps.response.status import WPS_STATUS
 from pywps.response import WPSResponse
 from pywps.inout.formats import FORMATS
 
-from pywps._compat import PY2
-
-if PY2:
-    import urlparse
-    from urllib import urlencode
-else:
-    import urllib.parse as urlparse
-    from urllib.parse import urlencode
+import urllib.parse as urlparse
+from urllib.parse import urlencode
 
 LOGGER = logging.getLogger("PYWPS")
 
@@ -39,7 +33,7 @@ class ExecuteResponse(WPSResponse):
         :param uuid: string this request uuid
         """
 
-        super(self.__class__, self).__init__(wps_request, uuid)
+        super(ExecuteResponse, self).__init__(wps_request, uuid)
 
         self.process = kwargs["process"]
         self.outputs = {o.identifier: o for o in self.process.outputs}
